@@ -33,7 +33,7 @@ class Calendar extends \Flake\Core\Model\Db {
     const LABELFIELD = "components";
 
     protected $aData = [
-        "components" => ""
+        "components" => "",
     ];
 
     function hasInstances() {
