@@ -61,7 +61,6 @@ class Users extends \Flake\Core\Controller {
         $aUsers = [];
         $oUsers = \Baikal\Model\User::getBaseRequester()->execute();
 
-        reset($oUsers);
         foreach ($oUsers as $user) {
             $aUsers[] = [
                 "linkcalendars"    => \BaikalAdmin\Controller\Users::linkCalendars($user),
@@ -101,7 +100,7 @@ class Users extends \Flake\Core\Controller {
     protected function initForm() {
         if ($this->actionEditRequested() || $this->actionNewRequested()) {
             $aOptions = [
-                "closeurl" => self::link()
+                "closeurl" => self::link(),
             ];
 
             $this->oForm = $this->oModel->formForThisModelInstance($aOptions);
@@ -213,26 +212,26 @@ class Users extends \Flake\Core\Controller {
 
     function linkNew() {
         return self::buildRoute([
-            "new" => 1
+            "new" => 1,
         ]) . "#form";
     }
 
     static function linkEdit(\Baikal\Model\User $user) {
         return self::buildRoute([
-            "edit" => $user->get("id")
+            "edit" => $user->get("id"),
         ]) . "#form";
     }
 
     static function linkDelete(\Baikal\Model\User $user) {
         return self::buildRoute([
-            "delete" => $user->get("id")
+            "delete" => $user->get("id"),
         ]) . "#message";
     }
 
     static function linkDeleteConfirm(\Baikal\Model\User $user) {
         return self::buildRoute([
             "delete"  => $user->get("id"),
-            "confirm" => 1
+            "confirm" => 1,
         ]) . "#message";
     }
 
